Crate tokio_scheduler_macro

Crate tokio_scheduler_macro 

Attribute Macros

job
This macro is used to annotate a struct or a function as a job. Every job marked by this macro can be automatically registered to the job manager by calling auto_register_job fn from the job manager.