Crate tokio_scheduler_macro
tokio_
scheduler_
macro
2.0.0
All Items
Crate Items
Attribute Macros
Crate
tokio_
scheduler_
macro
Attribute Macros

job
This macro is used to annotate a struct or a function as a job. Every job marked by this macro can be automatically registered to the job manager by calling
auto_register_job
fn from the job manager.